package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Aug 17, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Render loads and renders a CI/CD pipeline template.
Detect inspects a directory to guess the language, platform, and docker usage.
type Options struct {
WithDocker bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.